==> libro-codemirror-0.1.7.tgz: package/es/lsp/lint.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
import { setDiagnostics } from '@codemirror/lint';
import { ViewPlugin } from '@codemirror/view';
import { DiagnosticSeverity } from '@difizen/libro-lsp';
import { posToOffset } from "./util.js";
var LintPlugin = /*#__PURE__*/function () {
  function LintPlugin(view, options) {
    _classCallCheck(this, LintPlugin);
    this.view = view;
    this.options = options;
    this.processDiagnostic();
  }
  _createClass(LintPlugin, [{
    key: "processDiagnostic",
    value: function processDiagnostic() {
      var _this = this;
      if (!this.options.lspProvider) {
        return;
      }
      this.options.lspProvider().then(function (_ref) {
        var lspConnection = _ref.lspConnection,
          virtualDocument = _ref.virtualDocument,
          editor = _ref.editor;
        if (!lspConnection) {
          return;
        }
        lspConnection.serverNotifications['textDocument/publishDiagnostics'].event(function (e) {
          var diagnostics = e.diagnostics.map(function (_ref2) {
            var _DiagnosticSeverity$E;
            var range = _ref2.range,
              message = _ref2.message,
              _ref2$severity = _ref2.severity,
              severity = _ref2$severity === void 0 ? DiagnosticSeverity.Information : _ref2$severity;
            var currentEditor = virtualDocument.getEditorAtVirtualLine({
              line: range.start.line,
              ch: range.start.character,
              isVirtual: true
            });

            // the diagnostic range must be in current editor
            if (editor !== currentEditor) {
              return;
            }
            var editorStart = virtualDocument.transformVirtualToEditor({
              line: range.start.line,
              ch: range.start.character,
              isVirtual: true
            });
            var offset;
            if (editorStart) {
              offset = posToOffset(_this.view.state.doc, {
                line: editorStart.line,
                character: editorStart.ch
              });
            }
            var editorEnd = virtualDocument.transformVirtualToEditor({
              line: range.end.line,
              ch: range.end.character,
              isVirtual: true
            });
            var end;
            if (editorEnd) {
              end = posToOffset(_this.view.state.doc, {
                line: editorEnd.line,
                character: editorEnd.ch
              });
            }
            return {
              from: offset,
              to: end,
              severity: (_DiagnosticSeverity$E = {}, _defineProperty(_DiagnosticSeverity$E, DiagnosticSeverity.Error, 'error'), _defineProperty(_DiagnosticSeverity$E, DiagnosticSeverity.Warning, 'warning'), _defineProperty(_DiagnosticSeverity$E, DiagnosticSeverity.Information, 'info'), _defineProperty(_DiagnosticSeverity$E, DiagnosticSeverity.Hint, 'info'), _DiagnosticSeverity$E)[severity],
              message: message
            };
          }).filter(isDiagnostic).sort(function (a, b) {
            switch (true) {
              case a.from < b.from:
                return -1;
              case a.from > b.from:
                return 1;
            }
            return 0;
          });
          _this.view.dispatch(setDiagnostics(_this.view.state, diagnostics));
        });
        return;
      }).catch(console.error);
    }
  }, {
    key: "update",
    value: function update() {
      //
    }
  }, {
    key: "destroy",
    value: function destroy() {
      //
    }
  }]);
  return LintPlugin;
}();
export var lspLint = function lspLint(options) {
  return [ViewPlugin.define(function (view) {
    return new LintPlugin(view, options);
  })];
};
function isDiagnostic(item) {
  return item !== undefined && item !== null && item.from !== null && item.to !== null && item.from !== undefined && item.to !== undefined;
}

==> libro-codemirror-0.2.2.tgz: package/es/lsp/lint.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }
function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor); } }
function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
import { setDiagnostics } from '@codemirror/lint';
import { ViewPlugin } from '@codemirror/view';
import { DiagnosticSeverity } from '@difizen/libro-lsp';
import { posToOffset } from "./util.js";
var LintPlugin = /*#__PURE__*/function () {
  function LintPlugin(view, options) {
    _classCallCheck(this, LintPlugin);
    this.view = view;
    this.options = options;
    this.processDiagnostic();
  }
  _createClass(LintPlugin, [{
    key: "processDiagnostic",
    value: function processDiagnostic() {
      var _this = this;
      if (!this.options.lspProvider) {
        return;
      }
      this.options.lspProvider().then(function (_ref) {
        var lspConnection = _ref.lspConnection,
          virtualDocument = _ref.virtualDocument,
          editor = _ref.editor;
        if (!lspConnection) {
          return;
        }
        lspConnection.serverNotifications['textDocument/publishDiagnostics'].event(function (e) {
          var diagnostics = e.diagnostics.map(function (_ref2) {
            var range = _ref2.range,
              message = _ref2.message,
              _ref2$severity = _ref2.severity,
              severity = _ref2$severity === void 0 ? DiagnosticSeverity.Information : _ref2$severity;
            var currentEditor = virtualDocument.getEditorAtVirtualLine({
              line: range.start.line,
              ch: range.start.character,
              isVirtual: true
            });

            // the diagnostic range must be in current editor
            if (editor !== currentEditor) {
              return;
            }
            var editorStart = virtualDocument.transformVirtualToEditor({
              line: range.start.line,
              ch: range.start.character,
              isVirtual: true
            });
            var offset;
            if (editorStart) {
              offset = posToOffset(_this.view.state.doc, {
                line: editorStart.line,
                character: editorStart.ch
              });
            }
            var editorEnd = virtualDocument.transformVirtualToEditor({
              line: range.end.line,
              ch: range.end.character,
              isVirtual: true
            });
            var end;
            if (editorEnd) {
              end = posToOffset(_this.view.state.doc, {
                line: editorEnd.line,
                character: editorEnd.ch
              });
            }
            return {
              from: offset,
              to: end,
              severity: _defineProperty(_defineProperty(_defineProperty(_defineProperty({}, DiagnosticSeverity.Error, 'error'), DiagnosticSeverity.Warning, 'warning'), DiagnosticSeverity.Information, 'info'), DiagnosticSeverity.Hint, 'info')[severity],
              message: message
            };
          }).filter(isDiagnostic).sort(function (a, b) {
            switch (true) {
              case a.from < b.from:
                return -1;
              case a.from > b.from:
                return 1;
            }
            return 0;
          });
          _this.view.dispatch(setDiagnostics(_this.view.state, diagnostics));
        });
        return;
      }).catch(console.error);
    }
  }, {
    key: "update",
    value: function update() {
      //
    }
  }, {
    key: "destroy",
    value: function destroy() {
      //
    }
  }]);
  return LintPlugin;
}();
export var lspLint = function lspLint(options) {
  return [ViewPlugin.define(function (view) {
    return new LintPlugin(view, options);
  })];
};
function isDiagnostic(item) {
  return item !== undefined && item !== null && item.from !== null && item.to !== null && item.from !== undefined && item.to !== undefined;
}
